OTelMetricsBridge class

Bridge class to connect FlutterMetricReporter metrics to OpenTelemetry metrics

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize() → void
Initialize the metrics bridge by subscribing to metrics streams
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordLifecycleState(String state) → void
Record lifecycle state changes
recordRouteChange({required String name, required String action}) → void
Record route change events
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance OTelMetricsBridge
final